==> hpmgmt-7.4.0b-vmware.tgz: opt/hp/hpsmh/data/htdocs/hmaserv/help/helpmap.js <==
// Copyright (C) 1998-2000 Compaq Computer Corporation

addMapping( 'cf-secur.php', null,       'ima00084.htm',     null);
addMapping( 'cf-sinfo.php', null,       'ima00080.htm',     null);
addMapping( 'sb-info.php',  null,       'ima00081.htm',     null);
addMapping( 'ex-res.php',   null,       'ima00083.htm',     null);
addMapping( 'ex-info.php',  null,       'ima00082.htm',     null);

addMapping( 'ms-flop.php',  null,       'ima00046.htm', null);

addMapping( 'ut-info.php',  null,       'ima00011.htm', null);

addMapping( 'rc-btlog.php', null,       'ima00012.htm', null);
addMapping( 'rc-devsw.php', null,       'ima00012.htm', null);
addMapping( 'rc-rbtwt.php', null,       'ima00012.htm', null);

addMapping( 'rc-crit.php',  null,       'ima00018.htm', null);
addMapping( 'rc-crmem.php', null,       'ima00019.htm', null);
addMapping( 'rc-iml.php',   null,       'ima00021.htm', null);

addMapping( 'rc-recov.php', null,       'ima00012.htm', null);
addMapping( 'rc-rboot.php', null,       'ima00017.htm', null);
addMapping( 'rc-env.php',   null,       'ima00013.htm', null);
addMapping( 'rc-power.php', null,       'ima00014.htm', null);
addMapping( 'rc-pconv.php', null,       'ima00015.htm', null);
addMapping( 'rc-rcomm.php', null,       'ima00016.htm', null);

addMapping( 'rc-ribrd.php', null,       'ima00023.htm', null);
addMapping( 'rc-rblog.php', null,       'ima00022.htm', null);
addMapping( 'rc-rbnic.php', null,       'ima00024.htm', null);

addMapping( 'sb-resmem.php', null,       'ima00150.htm', null);

==> hpmgmt-7.5.1a-vmware.tgz: opt/hp/hpsmh/data/htdocs/hmaserv/help/helpmap.js <==
// Copyright (C) 1998-2000 Compaq Computer Corporation

addMapping( 'cf-secur.php', null,       'ima00084.htm',     null);
addMapping( 'cf-sinfo.php', null,       'ima00080.htm',     null);
addMapping( 'sb-info.php',  null,       'ima00081.htm',     null);
addMapping( 'sb-cpu.php',  null,       'ima00081.htm#cpu',     null);
addMapping( 'sb-cart.php',  null,       'ima00081.htm',     null);
addMapping( 'ex-res.php',   null,       'ima00083.htm',     null);
addMapping( 'ex-info.php',  null,       'ima00082.htm',     null);

addMapping( 'ms-flop.php',  null,       'ima00046.htm', null);

addMapping( 'ut-info.php',  null,       'ima00011.htm', null);

addMapping( 'rc-btlog.php', null,       'ima00012.htm', null);
addMapping( 'rc-devsw.php', null,       'ima00012.htm', null);
addMapping( 'rc-rbtwt.php', null,       'ima00012.htm', null);

addMapping( 'rc-crit.php',  null,       'ima00018.htm', null);
addMapping( 'rc-crmem.php', null,       'ima00019.htm', null);
addMapping( 'rc-iml.php',   null,       'ima00021.htm', null);

addMapping( 'rc-recov.php', null,       'ima00012.htm', null);
addMapping( 'rc-rboot.php', null,       'ima00017.htm', null);
addMapping( 'rc-env.php',   null,       'ima00013.htm', null);
addMapping( 'rc-power.php', null,       'ima00014.htm', null);
addMapping( 'rc-pconv.php', null,       'ima00015.htm', null);
addMapping( 'rc-rcomm.php', null,       'ima00016.htm', null);

addMapping( 'rc-ribrd.php', null,       'ima00023.htm', null);
addMapping( 'rc-rblog.php', null,       'ima00022.htm', null);
addMapping( 'rc-rbnic.php', null,       'ima00024.htm', null);

addMapping( 'sb-resmem.php', null,       'ima00150.htm', null);
